@@ -324,29 +324,3 @@ void init_children_reaper(void)
 	/* init list of pids to watch for exit */
 	memset(children_list, 0x00, sizeof(children_list));
 }
-
-void check_exited_children(void)
-{
-	int loop;
-
-	for(loop=0; loop<n_children; loop++)
-	{
-		pid_t rc = waitpid(children_list[loop], NULL, WNOHANG | WUNTRACED);
-
-		/* error while waiting? */
-		if (rc == -1 && errno != ECHILD)
-			error_exit("check_exited_children: waitpid for pid %d failed\n", children_list[loop]);
-
-		if (rc != 0)
-		{
-			int n_pids_to_move = (n_children - loop) - 1;
-
-			if (n_pids_to_move > 0)
-				memmove(&children_list[loop], &children_list[loop + 1], sizeof(pid_t) * n_pids_to_move);
-
-			n_children--;
-			/* also decrease pointer! as we move the other pids up! */
-			loop--;
-		}
-	}
-}
