@@ -4,6 +4,7 @@
 #include <regex.h>
 #include <ctype.h>
 #include "mt.h"
+#include "mem.h"
 #include "help.h"
 #include "term.h"
 #include "utils.h"
@@ -11,7 +12,7 @@
 char *help_main_menu[] = {
 		"MultiTail lets you create one or more windows in",
 		"one terminal. In each window one can monitor one",
-		"or more logfils and(!)/or the output of external",
+		"or more logfiles and(!)/or the output of external",
 		"programs: when using multiple inputs, they get",
 		"automatically merged.",
 		"",
@@ -22,31 +23,51 @@ char *help_main_menu[] = {
 		"One can press the following keys:",
 		" ^q^     quit the program",
 		" ^F1^    this help",
+		" ^/^     search in all windows",
+		" ^shift^ + ^/^  highlight in all windows",
+		" ^b^     scroll back",
+		" ^B^     scroll back in ALL windows merged into",
+		"       one window",
+		" ^I^     toggle case sensitivity for searches",
 		" ^a^     add a new window or add another file/",
 		"       program to an existing window",
 		" ^d^     delete a window (or a file/program from a",
 		"       window)",
 		" ^s^     swap the location of 2 windows",
 		" ^e^     enter/edit regular expressions",
+		" ^f^     enter/edit in line filter regexps",
 		" ^c^     set/change colors (only works if your",
 		"       terminal supports colors)",
+		" ^C^     edit the r/g/b components of a color",
 		" ^b^     scrollback in the buffer of a window",
 		" ^v^     toggle vertical split",
 		" ^0^...^9^ set a mark in a window so that you can",
 		"       easily see what has changed since the last",
 		"       time you looked",
+		" ^R^     restart a window",
+		" ^Y^     send a signal to a window (for commands)",
+		" ^y^     set linewrap",
+		" ^o^     wipe (clear) a window",
+		" ^O^     wipe all windows",
+		" ^T^     truncate a logfile",
+		" ^g^     make screendump",
 		" ^r^     redraw screen",
+		" ^I^     toggle case sensitivity for searches",
+		" ^l^     list keybindings",
 		" ^i^     info",
 		" ^t^     statistics",
 		" ^j^     set window sizes",
-		" ^z^     hide a window temporarily",
+		" ^z^     hide/unhide a window",
+		" ^u^     hide all windows but the one selected",
+		" ^U^     unhide all windows",
 		" ^w^     write a script which starts multitail",
 		"       with the current settings (the files that",
 		"       are monitored, regular expressions, etc.)",
 		" ^n^     clear the buffer of a window",
 		" ^m^     set the size of a buffer",
 		" ^k^     enter a (limited) terminal-mode",
-		" ^p^     pause multitail",
+		" ^p^     pause all windows",
+		" ^P^     (un-)pause one window",
 		"",
 		"",
 		"",
@@ -64,7 +85,7 @@ char *help_add_file_or_cmd[] = {
 		"or the output of a command.",
 		" ^f^     selects a file",
 		" ^c^     selects a commands",
-		" ^q^     abort",
+		" ^ctrl+g^     abort",
 		"",
 		"Commands are executed in their own virtual tty to",
 		"force line-buffered output. They are executed by",
@@ -73,6 +94,19 @@ char *help_add_file_or_cmd[] = {
 		NULL
 	};
 
+char *help_list_keybindings[] = {
+		"This screen lists the keybindings you defined in",
+		"the MultiTail configurationfile which is located",
+		"in /etc/multitail.conf. The keybindings only",
+		"work in the main screen.",
+		"In this screen, you can press the followking",
+		"keys:",
+		" ^UP^    (cursor key UP) scroll up",
+		" ^DOWN^  (cursor key DOWN) scroll down",
+		" ^q^     abort",
+		NULL
+	};
+
 char *help_enter_filename_to_monitor[] = {
 		"Please enter the filename of the file you wish to",
 		"monitor. If the file is not in the directory you",
@@ -111,7 +145,7 @@ char *help_add_window_merge_subwin[] = {
 		"existing window. Lines from the logfiles/commands",
 		"in a window are then interleaved as they are",
 		"generated",
-		"Enter ^y^ or ^n^ here or ^q^ to abort.",
+		"Enter ^y^ or ^n^ here or ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -123,7 +157,7 @@ char *help_add_window_select_merge_window[] = {
 		"in a window are then interleaved as they are",
 		"generated",
 		"Here, select the window to merge with.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -161,7 +195,7 @@ char *help_ask_colors[] = {
 		"       use for selecting a color. You'll also be",
 		"       asked to enter the character that seperates",
 		"       each field in a line",
-		" ^q^     abort",
+		" ^ctrl+g^     abort",
 		"",
 		"Using colors only works if your terminal supports",
 		"this.",
@@ -207,7 +241,7 @@ char *help_ask_colors_select_scheme[] = {
 		"See the example *multitail.conf* which should've",
 		"been included with the MultiTail when you",
 		"installed it.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -231,7 +265,7 @@ char *help_add_file_display_diff[] = {
 		"want to see the difference between each run. In",
 		"that case press ^y^ here. To see all output every",
 		"time, press ^n^.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		"",
 		"On the commandline you can select this behaviour",
 		"with the ^-R^ switch.",
@@ -248,7 +282,7 @@ char *help_enter_regexp_select_window[] = {
 		"then one file/command is displayed in a window,",
 		"you'll get another selection box after this one",
 		"where you can select a \"sub-window\".",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -257,7 +291,7 @@ char *help_enter_regexp_select_subwindow[] = {
 		"more then one file/command. You now have to",
 		"select the \"sub-window\" to edit the regular",
 		"expressions for.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -268,6 +302,10 @@ char *help_regexp_menu[] = {
 		"       of 10 per file/command)",
 		" ^e^     edit an existing regexp",
 		" ^d^     delete one of the existing regexps",
+		" ^D^     move an entry down, this also changes",
+		"       priority of this reg.exp.",
+		" ^U^     move an entry up",
+		" ^r^     reset counter",
 		" ^q^/^x^   leave this menu",
 		NULL
 	};
@@ -289,7 +327,7 @@ char *help_negate_regexp[] = {
 		"regular expression processing: should it match",
 		"when the regexp matches, or should it match when",
 		"the regexp does *not* match?",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -308,7 +346,7 @@ char *help_regexp_usage[] = {
 		" ^b^     combination of ^C^ and ^B^",
 		" ^x^     if a regexp matches, a command is",
 		"       executed",
-		" ^q^     abort",
+		" ^ctrl+g^     abort",
 		NULL
 	};
 
@@ -341,7 +379,7 @@ char *help_delete_select_window[] = {
 		"remove the complete window including all",
 		"\"subwindows\" or just the first one (the first",
 		"file/command).",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -349,7 +387,7 @@ char *help_delete_window_delete_all_subwin[] = {
 		"This window contains more then one logfile /",
 		"command. Here you select if you want to remove all",
 		"\"subwindows\" or just the first file/command.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -357,7 +395,7 @@ char *help_delete_select_subwindow[] = {
 		"This window contains more then one logfile /",
 		"command. Select the file / command you wish to",
 		"remove from this window.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -365,7 +403,7 @@ char *help_swap_win1[] = {
 		"You have indicated that you want to swap the",
 		"location (on the screen) of 2 windows.",
 		"Please select the first window.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -373,7 +411,7 @@ char *help_swap_win2[] = {
 		"You have indicated that you want to swap the",
 		"location (on the screen) of 2 windows.",
 		"Please select the second window.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -383,7 +421,7 @@ char *help_toggle_colors_select_window[] = {
 		"If a window consists of more then one logfile or",
 		"command, you'll be asked to select the file or",
 		"command in that window to change the colors for.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -391,7 +429,7 @@ char *help_toggle_colors_select_subwindow[] = {
 		"This window contains more then one logfile /",
 		"command. Select the file / command you wish to",
 		"change the colors for.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -415,13 +453,6 @@ char *help_window_closed[] = {
 		NULL
 	};
 
-char *help_pause[] = {
-		"Pause let's you pause MultiTail. And that is what",
-		"it is doing: nothing but waiting until you tell it",
-		"to continue.",
-		NULL
-	};
-
 char *help_write_script[] = {
 		"This function writes a script to disk which will",
 		"start MultiTail in the same state it now is. This",
@@ -435,38 +466,44 @@ char *help_write_script[] = {
 	};
 
 char *help_statistics[] = {
+		"In this menu one can select the window or sub-",
+		"window to display the statistics off.",
+		" ^r^     reset ALL counters for ALL windows",
+		" ^ctrl+g^     exit window",
+		NULL,
+	};
+
+char *help_statistics_popup[] = {
 		"Apart from how long MultiTail has been running, it",
 		"also shows a couple of statistics for each window.",
 		"It also shows some statistics on the interval",
 		"between each show line in each window.",
 		" *average*             average interval",
 		" *standard deviation*  speaks for itself",
-		" *tendency*            wether the average tends to",
-		"                     become larger or smaller",
 		"",
-		" ^r^     resets the counters",
-		" ^q^     exit this screen",
+		" ^r^     reset the counters for this window",
+		" ^ctrl+g^     exit window",
 		NULL
 	};
 
-char *help_set_mark[] = {
+char *help_set_buffering[] = {
 		"In this window you can control the buffering for",
 		"each window. The first question lets you select",
 		"on what window you want to set the buffering",
 		"parameters:"
 		" ^a^     set on all windows",
 		" ^o^     set on one window",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
-char *help_set_mark_store_what[] = {
+char *help_set_buffering_store_what[] = {
 		"Here you set what should be buffered.",
 		" ^a^     buffer all lines that are monitored",
 		" ^m^     only buffer the lines that match the",
 		"       configured regular expressions. If you have",
 		"       not set any regexps, everything is stored.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -477,10 +514,10 @@ char *help_enter_number_of_lines_to_store[] = {
 		NULL
 	};
 
-char *help_set_mark_select_window[] = {
+char *help_set_buffering_select_window[] = {
 		"Here you select the window on which you want to",
 		"set the buffer limits.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -488,7 +525,7 @@ char *help_hide_window[] = {
 		"Select the window that you want to (un-)hide. When",
 		"a window is hidden, it is not displayed: logging",
 		"and filtering continues as usual.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -496,9 +533,9 @@ char *help_set_windowsizes[] = {
 		"Here you can set the sizes of windows. The width",
 		"can only set for *all* windows, the height can be",
 		"set for each individual window.",
-		" ^w^     set the width for all windows",
+		" ^m^     manage columns: add a column, set width",
 		" ^h^     set the height for a window",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -522,6 +559,9 @@ char *help_set_window_height[] = {
 		"switch.",
 		"One can only set the window height if there are at",
 		"least 2 windows on the screen.",
+		"When you enter '0' MultiTail will automatically",
+		"set the height. The height must be either 0 or",
+		"more then one.",
 		"Press enter on an empty line to abort.",
 		NULL
 	};
@@ -530,7 +570,7 @@ char *help_set_window_height_select_window[] = {
 		"You're about to set the height of a window. The",
 		"first step is to select the window which you want",
 		"to resize.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -553,8 +593,11 @@ char *help_scrollback_help[] = {
 		" ^c^     set colors",
 		" ^f^/^/^   search for a string in the buffer",
 		" ^n^     find the next occurence",
+		" ^Y^     toggle linewrap. if linewrap is disabled,",
+		"       one can scroll left/right with the cursor-",
+		"       keys.",
 		" ^s^     save the buffer to a file",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
@@ -582,12 +625,11 @@ char *help_scrollback_no_mark[] = {
 
 char *help_scrollback_select_window[] = {
 		"Select the window in which you want to scrollback.",
-		"Press ^q^ to abort.",
+		"Press ^ctrl+g^ to abort.",
 		NULL
 	};
 
 char *help_scrollback_edit_search_string[] = {
-		/*2345678901234567890123456789012345678901234567890 */
 		"Enter the string to search for in the scrollback-",
 		"buffer. The search-string can be a regular",
 		"expression.",
@@ -595,10 +637,278 @@ char *help_scrollback_edit_search_string[] = {
 		NULL
 	};
 
+char *help_pause_a_window[] = {
+		"Select the window to (un-)pause. When a window is",
+		"paused, it won't be updated until the window is",
+		"un-paused. NOTHING will be discarded.",
+		NULL
+	};
+
+char *help_ask_colors_select_color[] = {
+		"Select the color or attribute to use.",
+		NULL
+	};
+
+char *help_set_vertical_split_n_win[] = {
+		"Enter the number of columns to split the terminal",
+		"in. If you press 'j' in the menu, you can also",
+		"select the number of windows per column.",
+		NULL
+	};
+
+char *help_wipe_window[] = {
+		"Press the number of the window to wipe. The number",
+		"can be found in the status-line of the windows.",
+		"Press 'r' to redraw the windows so that you can",
+		"see their contents again.",
+		NULL
+	};
+
+char *help_select_colorschemes[] = {
+		"Move the cursor with the cursor keys to the a",
+		"colorscheme. Then press space to select and again",
+		"to unselect. Press enter to submit or ^g to abort.",
+		NULL
+	};
+
+char *help_manage_cols[] = {
+		"Press ^a^ to add a column, ^d^ to delete one and press",
+		"^e^ to set the number of windows in a column.",
+		NULL
+	};
+
+char *help_set_linewrap[] = {
+		"In this menu one can set how the wrap the text in",
+		"windows.",
+		" ^l^  start at the left and cut of at the right",
+		" ^a^  try to display everything",
+		" ^r^  cut off at the left",
+		" ^s^  cut right before the syslog process name",
+		" ^S^  cut right after the syslog process name",
+		" ^o^  enter a position where to cut",
+		" Press ctrl+g to abort.",
+		NULL
+	};
+
+char *help_enter_stripper_select_window[] = {
+		"Select window to apply the stripping to.",
+		NULL
+	};
+
+char *help_enter_stripper_select_subwindow[] = {
+		"Select the sub-window to apply the stripping to.",
+		NULL
+	};
+
+char *help_redirect_failed[] = {
+		"Sending the data which was retrieved from a tail-",
+		"process to some other process or file failed.",
+		"Maybe the disk is full or the process died?",
+		NULL
+	};
+
+char *help_stripper_type[] = {
+		" ^e^   filter by using a regular expression",
+		" ^r^   filter by specifying the character-range",
+		" ^c^   specify a column to strip - you'll be asked",
+		"     to enter a delimiter as well",
+		NULL
+	};
+
+char *help_stripper_start_offset[] = {
+		"Please enter the offset from where to strip the",
+		"string. The offset starts at 0.",
+		NULL
+	};
+
+char *help_stripper_end_offset[] = {
+		"Please enter the offset upto where the string will",
+		"be filtered. Upto, not including!",
+		NULL
+	};
+
+char *help_stripper_delimiter[] = {
+		"When selecting stripping by column-number you need",
+		"to enter the delimiter for each column. Usually",
+		"you would enter a space here.",
+		NULL
+	};
+
+char *help_stripper_col_nr[] = {
+		"Enter the number of the column here. The first one",
+		"is at offset 0.",
+		NULL
+	};
+
+char *help_error_write_script_create_file[] = {
+		"There was an error writing the scriptfile. Maybe",
+		"the filesystem is full or the media is damaged?",
+		NULL
+	};
+
+char *help_column_width[] = {
+		"Enter the number of characters that will fit in a",
+		"line for this column.",
+		NULL
+	};
+
+char *help_n_win_per_col[] = {
+		"Enter the number of windows that will fit in this",
+		"column (vertically).",
+		NULL
+	};
+
+char *help_send_signal_select_window[] = {
+		"Select the window to send the signal to. Please",
+		"note that sending a signal may cause the process",
+		"(for example the tail-process when monitoring a",
+		"logfile) to exit and thereby closing the window.",
+		NULL
+	};
+
+char *help_send_signal_window_send_to_all_subwin[] = {
+		"Would you like to send the signal to all sub-",
+		"windows?",
+		NULL
+	};
+
+char *help_send_signal_select_subwindow[] = {
+		"Select the subwindow to send the signal to.",
+		NULL
+	};
+
+char *help_send_signal_failed[] = {
+		"Sending the signal to the process failed. This",
+		"should not happen.",
+		NULL
+	};
+
+char *help_select_signal[] = {
+		"Select the signal to send. Please note that some",
+		"signals may cause the process to exit and closing",
+		"the window",
+		NULL
+	};
+
+char *help_screendump_select_file[] = {
+		"Select the file to write the screendump to.",
+		"Existing files will be overwritten.",
+		NULL
+	};
+
+char *help_screendump_select_win[] = {
+		"Select the window to dump to a screendump-file.",
+		"The output file will be plain ascii.",
+		NULL
+	};
+
+char *help_truncate_file_select_window[] = {
+		"Select window. By selecting a window you select",
+		"the file to truncate.",
+		NULL
+	};
+
+char *help_truncate_file_select_subwindow[] = {
+		"As the window you selected contains several sub-",
+		"windows, you need to select now the subwindow to",
+		"truncate.",
+		NULL
+	};
+
+char *help_truncate_areyousure[] = {
+		"Are you really sure you want to truncate this",
+		"file? This cannot be undone!",
+		NULL
+	};
+
+char *help_truncate_failed[] = {
+		"There was an error truncating the file. Please",
+		"check the permissions on the file.",
+		NULL
+	};
+
+char *help_truncate_only_logfiles[] = {
+		"One can only truncate logfiles and not processes.",
+		NULL
+	};
+
+char *help_select_color_and_attributes[] = {
+		"Select the foreground and background color to use.",
+		"You can select one foreground and one background-",
+		"color but you can select multiple attributes.",
+		"Press the space-bar to select or un-select.",
+		NULL
+	};
+
+char *help_cannot_change_color[] = {
+		"Your terminal doesn't support chaning the red,",
+		"green and blue values of a color.",
+		NULL
+	};
+
+char *help_edit_color_edit[] = {
+		"Depending on the range you selected (by pressing",
+		"the cursor up and down key), you can enter a value",
+		"for either red, green or blue in the range of",
+		"0-1000, 0-255 or 00-ff (hex value).",
+		NULL
+	};
+
+char *help_edit_color[] = {
+		"In this menu one can edit the values for the red,",
+		"the green and the blue component of a color.",
+		"Move the '>' with the up and down cursorkeys in",
+		"front of the range in which you want to enter the",
+		"value. The uppermost range being 0 upto 1000, the",
+		"middle 0-255 and the lowest also 0-255 but entered",
+		"in hexadecimal values.",
+		" ^r^   edit the red component",
+		" ^g^   edit the green component",
+		" ^b^   edit the blue component",
+		" ^c^   give the color a name/description",
+		NULL
+	};
+
+char *help_edit_color_change_name[] = {
+		"One can give this specific red, green and blue",
+		"values a name. Like roses-red or so. This name can",
+		"then be used in a colorscheme.",
+		NULL
+	};
+
+char *help_hide_but_window[] = {
+		"Select which window to keep open. All other",
+		"windows will be closed.",
+		NULL
+	};
+
+char *help_search_in_all_windows[] = {
+		"This functionality lets you search in all windows.",
+		"The result will be merged into one new window.",
+		NULL
+	};
+
+char *help_highlight_in_all_windows[] = {
+		/*2345678901234567890123456789012345678901234567890 */
+		"This functionality lets you search in all windows.",
+		"All lines with the search-string will be",
+		"highlighted (displayed in reverse).",
+		NULL
+	};
+
+#if 0
+char *help_bla[] = {
+		/*2345678901234567890123456789012345678901234567890 */
+		"FIXME", /* FIXME */
+		NULL
+	};
+#endif
+
 help_t	help[] =
 {
 	{ HELP_MAIN_MENU,			help_main_menu },
 	{ HELP_ADD_FILE_OR_CMD,			help_add_file_or_cmd },
+	{ HELP_LIST_KEYBINDINGS,		help_list_keybindings },
 	{ HELP_ENTER_FILENAME_TO_MONITOR,	help_enter_filename_to_monitor },
 	{ HELP_ENTER_CMD_TO_MONITOR,		help_enter_cmd_to_monitor },
 	{ HELP_ADD_WINDOW_MERGE_SUBWIN,		help_add_window_merge_subwin },
@@ -612,8 +922,11 @@ help_t	help[] =
 	{ HELP_ADD_FILE_DISPLAY_DIFF,		help_add_file_display_diff },
 	{ HELP_MERGE_ANOTHER_WINDOW,		help_merge_another_window },
 	{ HELP_ENTER_REGEXP_SELECT_WINDOW,	help_enter_regexp_select_window },
+	{ HELP_ENTER_STRIPPER_SELECT_WINDOW,	help_enter_stripper_select_window },
 	{ HELP_ENTER_REGEXP_SELECT_SUBWINDOW,	help_enter_regexp_select_subwindow },
+	{ HELP_ENTER_STRIPPER_SELECT_SUBWINDOW,	help_enter_stripper_select_subwindow },
 	{ HELP_REGEXP_MENU,			help_regexp_menu },
+
 	{ HELP_ENTER_REGEXP,			help_enter_regexp },
 	{ HELP_NEGATE_REGEXP,			help_negate_regexp },
 	{ HELP_REGEXP_USAGE,			help_regexp_usage },
@@ -628,13 +941,12 @@ help_t	help[] =
 	{ HELP_TOGGLE_COLORS_SELECT_SUBWINDOW,	help_toggle_colors_select_subwindow },
 	{ HELP_FAILED_TO_START_TAIL,		help_failed_to_start_tail },
 	{ HELP_WINDOW_CLOSED,			help_window_closed },
-	{ HELP_PAUSE,				help_pause },
 	{ HELP_WRITE_SCRIPT,			help_write_script },
 	{ HELP_STATISTICS,			help_statistics },
-	{ HELP_SET_MARK,			help_set_mark },
-	{ HELP_SET_MARK_STORE_WHAT,		help_set_mark_store_what },
+	{ HELP_SET_BUFFERING,			help_set_buffering },
+	{ HELP_SET_BUFFERING_STORE_WHAT,	help_set_buffering_store_what },
 	{ HELP_ENTER_NUMBER_OF_LINES_TO_STORE,	help_enter_number_of_lines_to_store },
-	{ HELP_SET_MARK_SELECT_WINDOW,	 	help_set_mark_select_window },
+	{ HELP_SET_BUFFERING_SELECT_WINDOW, 	help_set_buffering_select_window },
 	{ HELP_HIDE_WINDOW,			help_hide_window },
 	{ HELP_SET_WINDOWSIZES,			help_set_windowsizes },
 	{ HELP_SET_WINDOW_WIDTH,		help_set_window_width },
@@ -647,10 +959,42 @@ help_t	help[] =
 	{ HELP_SCROLLBACK_SAVEFILE_ENTER_FILENAME,	help_scrollback_savefile_enter_filename },
 	{ HELP_SCROLLBACK_SELECT_WINDOW,	help_scrollback_select_window },
 	{ HELP_SCROLLBACK_EDIT_SEARCH_STRING,	help_scrollback_edit_search_string },
-#if 0
-	{ HELP_SCROLLBACK_DELETE_MARK_NO_MARK,	help_scrollback_delete_mark_no_mark },
-	{ HELP_SCROLLBACK_DELETE_MARK_SELECT_WINDOW,	help_scrollback_delete_mark_select_window },
-#endif
+	{ HELP_PAUSE_A_WINDOW,			help_pause_a_window },
+	{ HELP_ASK_COLORS_SELECT_COLOR,		help_ask_colors_select_color },
+	{ HELP_SET_VERTICAL_SPLIT_N_WIN, 	help_set_vertical_split_n_win },
+	{ HELP_MANAGE_COLS,			help_manage_cols },
+	{ HELP_WIPE_WINDOW,			help_wipe_window },
+	{ HELP_SELECT_COLORSCHEMES,		help_select_colorschemes },
+	{ HELP_SET_LINEWRAP,			help_set_linewrap },
+	{ HELP_REDIRECT_FAILED,			help_redirect_failed },
+	{ HELP_STRIPPER_TYPE,			help_stripper_type },
+	{ HELP_STRIPPER_START_OFFSET,		help_stripper_start_offset },
+	{ HELP_STRIPPER_END_OFFSET,		help_stripper_end_offset },
+	{ HELP_STRIPPER_DELIMITER,		help_stripper_delimiter },
+	{ HELP_STRIPPER_COL_NR,			help_stripper_col_nr },
+	{ HELP_ERROR_WRITE_SCRIPT_CREATE_FILE,	help_error_write_script_create_file },
+	{ HELP_COLUMN_WIDTH,			help_column_width },
+	{ HELP_N_WIN_PER_COL,			help_n_win_per_col },
+	{ HELP_SEND_SIGNAL_SELECT_WINDOW,	help_send_signal_select_window },
+	{ HELP_SEND_SIGNAL_WINDOW_SEND_TO_ALL_SUBWIN, help_send_signal_window_send_to_all_subwin },
+	{ HELP_SEND_SIGNAL_SELECT_SUBWINDOW,	help_send_signal_select_subwindow },
+	{ HELP_SEND_SIGNAL_FAILED,		help_send_signal_failed },
+	{ HELP_SELECT_SIGNAL,			help_select_signal },
+	{ HELP_SCREENDUMP_SELECT_FILE,		help_screendump_select_file },
+	{ HELP_SCREENDUMP_SELECT_WIN,		help_screendump_select_win },
+	{ HELP_TRUNCATE_FILE_SELECT_WINDOW,	help_truncate_file_select_window },
+	{ HELP_TRUNCATE_FILE_SELECT_SUBWINDOW,	help_truncate_file_select_subwindow },
+	{ HELP_TRUNCATE_AREYOUSURE,		help_truncate_areyousure },
+	{ HELP_TRUNCATE_FAILED,			help_truncate_failed },
+	{ HELP_TRUNCATE_ONLY_LOGFILES,		help_truncate_only_logfiles },
+	{ HELP_SELECT_COLOR_AND_ATTRIBUTES,	help_select_color_and_attributes },
+	{ HELP_CANNOT_EDIT_COLOR,               help_cannot_change_color },
+	{ HELP_EDIT_COLOR_EDIT,			help_edit_color_edit },
+	{ HELP_EDIT_COLOR,			help_edit_color },
+	{ HELP_EDIT_COLOR_CHANGE_NAME,		help_edit_color_change_name },
+	{ HELP_HIDE_BUT_WINDOW,			help_hide_but_window },
+	{ HELP_SEARCH_IN_ALL_WINDOWS,		help_search_in_all_windows },
+	{ HELP_HIGHLIGHT_IN_ALL_WINDOWS,	help_highlight_in_all_windows },
 	{ -1, NULL }
 };
 
@@ -681,11 +1025,11 @@ void show_help(int what_help)
 
 		wattron(winb -> win, A_STANDOUT);
 		if (line_cnt > 15)
-			mvwprintw(winb -> win, 0, 2, "Use cursor UP/DOWN to scroll, Q to exit");
+			mvwprintw(winb -> win, 0, 2, "Use cursor UP/DOWN to scroll, ctrl+g to exit");
 		else
-			mvwprintw(winb -> win, 0, 2, "Press Q to exit");
+			mvwprintw(winb -> win, 0, 2, "Press ctrl+g to exit");
 		wattroff(winb -> win, A_STANDOUT);
-		mydoupdate(winb -> win);
+		mydoupdate();
 
 		for(;;)
 		{
@@ -698,25 +1042,37 @@ void show_help(int what_help)
 				werase(win -> win);
 				for(loop=pos; loop<min(pos + 15, line_cnt); loop++)
 				{
-					escape_print(win -> win, loop - pos, 0, help[index].text[loop]);
+					escape_print(win, loop - pos, 0, help[index].text[loop]);
 				}
 
 				ppos = pos;
 
-				mydoupdate(win -> win);
+				mydoupdate();
 			}
 
-			c = wait_for_keypress(-1);	/* -1!!! or bad recursive loops will happen! */
+			c = wait_for_keypress(-1, 0, NULL, 1);	/* -1!!! or bad recursive loops will happen! */
 
 			if (c == KEY_UP && pos > 0)
 			{
 				pos--;
 			}
-			else if (c == KEY_DOWN && pos < (line_cnt - 1))
+			else if ((c == KEY_DOWN || c == 13) && pos < (line_cnt - 1))
 			{
 				pos++;
 			}
-			else if (tolower(c) == 'q')
+			else if (c == KEY_PPAGE && pos >= 15)
+			{
+				pos -= 15;
+			}
+			else if ((c == KEY_NPAGE || c == ' ') && (pos + 15) < (line_cnt - 1))
+			{
+				pos += 15;
+			}
+			else if (c == KEY_HOME && pos > 0)
+			{
+				pos = 0;
+			}
+			else if (tolower(c) == 'q' || c == 7)
 			{
 				break;
 			}
