@@ -91,5 +91,7 @@ typedef struct
 #define HELP_EDIT_COLOR	8800
 #define HELP_EDIT_COLOR_CHANGE_NAME	8900
 #define HELP_HIDE_BUT_WINDOW	9000
+#define HELP_SEARCH_IN_ALL_WINDOWS	9100
+#define HELP_HIGHLIGHT_IN_ALL_WINDOWS	9200
 
 void show_help(int what_help);
