@@ -27,6 +27,7 @@
 #include "mem.h"
 #include "mt.h"
 #include "term.h"
+#include "globals.h"
 #include "utils.h"
 
 
@@ -86,19 +87,9 @@ ssize_t WRITE(int fd, char *whereto, size_t len)
 	return cnt;
 }
 
-/** get_load
- * - in:      nothing
- * - returns: char *
- * this function returns a string containing the current load of the system
- * multitail is running on. format: %1.2f %1.2f %1.2f
- * the string is malloc()ed so the caller should free() things
- */
-char *get_load(void)
+void get_load_values(double *v1, double *v2, double *v3)
 {
 #if !defined(__UCLIBC__) && (defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__GNU__) || defined(__sun) || defined(sun))
-	double loadavg[3];
-	char *str = (char *)mymalloc(LOADAVG_STR_LEN, "get_load: loadavg string");
-
 #if defined(__GLIBC__) && ( __GLIBC__ < 2 || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 2))
 	/* Older glibc doesn't have getloadavg() - use sysinfo() */
 	/* thanks to Ville Herva for this code! */
@@ -114,21 +105,22 @@ char *get_load(void)
 		error_exit("get_load: sysinfo() failed\n");
 	}
 
-	loadavg[0] = (double)si.loads[0] / scale;
-	loadavg[1] = (double)si.loads[1] / scale;
-	loadavg[2] = (double)si.loads[2] / scale;
+	*v1 = (double)si.loads[0] / scale;
+	*v2 = (double)si.loads[1] / scale;
+	*v3 = (double)si.loads[2] / scale;
 #else
+	double loadavg[3];
 	if (getloadavg(loadavg, 3) == -1)
 	{
 		/* see comment on sysinfo() */
 		error_exit("get_load: getloadavg() failed\n");
 	}
+	*v1 = loadavg[0];
+	*v2 = loadavg[1];
+	*v3 = loadavg[2];
 #endif
-	snprintf(str, LOADAVG_STR_LEN, "%1.2f %1.2f %1.2f", loadavg[0], loadavg[1], loadavg[2]);
-
-	return str;
 #else
-	return mystrdup("", "get_load:");
+	*v1 = *v2 = *v3 = -1.0;
 #endif
 }
 
@@ -325,22 +317,6 @@ char * amount_to_str(long long int amount)
 	return out;
 }
 
-char * replace_string(char *in, int pos_start, int pos_end, char *with_what)
-{
-	int str_len_in = strlen(in);
-	int str_len_ww = strlen(with_what);
-	int n_remove = (pos_end - pos_start) + 1; /* +1 => including pos_end! */
-	int new_len = str_len_in + str_len_ww - n_remove;
-	char *out = mymalloc(new_len + 1, "replace_string: new string"); /* +1 => 0x00 */
-
-	memcpy(out, in, pos_start);
-	memcpy(&out[pos_start], with_what, str_len_ww);
-	memcpy(&out[pos_start + str_len_ww], &in[pos_end + 1], str_len_in - (pos_end + 1));
-	out[new_len] = 0x00;
-
-	return out;
-}
-
 struct passwd *getuserinfo(void)
 {
 	struct passwd *pp = getpwuid(geteuid());
@@ -350,6 +326,19 @@ struct passwd *getuserinfo(void)
 	return pp;
 }
 
+char * getusername(void)
+{
+	static char username[128] = { 0 };
+
+	if (!username[0])
+	{
+		strncpy(username, getuserinfo() -> pw_name, sizeof(username));
+		username[sizeof(username) - 1] = 0x00;
+	}
+
+	return username;
+}
+
 /* these are there because AIX/IRIX can return EINTR for those */
 int myopen(char *path, int mode)
 {
@@ -693,3 +682,59 @@ void get_now_ts(char *format_str, char *dest, int dest_size)
 
 	(void)strftime(dest, dest_size, format_str, ptm);
 }
+
+void duplicate_re_array(re *pre_in, int n_rein, re **pre_out, int *n_reout)
+{
+	int loop, old_n = *n_reout;
+
+	*n_reout += n_rein;
+	*pre_out = (re *)myrealloc(*pre_out, (*n_reout) * sizeof(re), "duplicate re array");
+
+	for(loop=0; loop<n_rein; loop++)
+	{
+		memcpy(&(*pre_out)[loop + old_n], &pre_in[loop], sizeof(re));
+		memset(&(*pre_out)[loop + old_n].regex, 0x00, sizeof(regex_t));
+		(*pre_out)[loop + old_n].regex_str = mystrdup(pre_in[loop].regex_str, "regex str");
+		if (regcomp(&(*pre_out)[loop + old_n].regex, (*pre_out)[loop + old_n].regex_str, REG_EXTENDED))
+			error_exit("duplicate_re_array: regex '%s' suddenly failed to compile\n", (*pre_out)[loop + old_n].regex_str);
+	}
+}
+
+int find_filterscheme(char *name)
+{
+	int loop;
+
+	for(loop=0; loop<n_fs; loop++)
+	{
+		if (strcmp(pfs[loop].fs_name, name) == 0)
+			return loop;
+	}
+
+	return -1;
+}
+
+void compile_re(regex_t *whereto, char *what)
+{
+	/* compile & store regular expression */
+	int rc = regcomp(whereto, what, REG_EXTENDED);
+	if (rc != 0)
+		error_exit("failed to compile regular expression '%s': %s\n", what, convert_regexp_error(rc, whereto));
+}
+
+void grow_mem_if_needed(char **what, int *cur_len, int requested_len)
+{
+	char changed = 0;
+
+	while(*cur_len < requested_len)
+	{
+		changed = 1;
+
+		if (*cur_len)
+			(*cur_len) *= 2;
+		else
+			*cur_len = 128;
+	}
+
+	if (changed)
+		*what = myrealloc(*what, *cur_len, "grow_mem_if_needed");
+}
