@@ -1,6 +1,5 @@
 int myrand(int max);
 char * read_line_fd(int fd);
-char * get_load(void);
 int get_vmsize(pid_t pid);
 void stop_process(int pid);
 void delete_array(char **list, int n);
@@ -10,7 +9,6 @@ char * convert_regexp_error(int error, const regex_t *preg);
 char check_date(void);
 ssize_t WRITE(int fd, char *whereto, size_t len);
 char * amount_to_str(long long int amount);
-char * replace_string(char *in, int pos_start, int pos_end, char *with_what);
 struct passwd *getuserinfo(void);
 int myopen(char *path, int mode);
 int myclose(int fd);
@@ -35,6 +33,12 @@ char *find_next_par(char *start);
 int mydup(int old_fd);
 char * term_t_to_string(term_t term);
 void get_now_ts(char *format_str, char *dest, int dest_size);
+void duplicate_re_array(re *pre_in, int n_rein, re **pre_out, int *n_reout);
+int find_filterscheme(char *name);
+void compile_re(regex_t *whereto, char *what);
+void grow_mem_if_needed(char **what, int *cur_len, int requested_len);
+void get_load_values(double *v1, double *v2, double *v3);
+char * getusername(void);
 
 #define min(x, y) ((x)<(y)?(x):(y))
 #define max(x, y) ((x)>(y)?(x):(y))
